{
const TOOLS_RUNNER_URL = "https://functions.yandexcloud.net/d4e0botd84pvt6ao7jq6";
const SHOWDOWN_URL = "https://cdnjs.cloudflare.com/ajax/libs/showdown/2.1.0/showdown.min.js";
const TOOL_ID = "95bdbee9-0973-4833-9c6b-8253813b8287";
const BLOCK_ID = "#rec907180531";

if (document.readyState !== "loading") {
  runTool();
} else {
  document.addEventListener("DOMContentLoaded", runTool);
}

const loadShowdown = new Promise((resolve, reject) => {
  const script = document.createElement("script");
  script.onload = resolve;
  script.onerror = reject;
  script.async = true;
  script.src = SHOWDOWN_URL;
  document.body.appendChild(script);
});

function populate(container, block, records) {
  const converter = new showdown.Converter();
  records.forEach(function (record, index) {
    item = block.cloneNode(true);
    item.id = `${block.id}_${index}`;
    if ("text" in record) {
      const text = item.querySelector(".t-text");
      text.innerHTML = converter.makeHtml(String(record.text));
    }
    container.appendChild(item);
    window.dispatchEvent(new Event("resize"));
  });
  container.dispatchEvent(new Event("collabza_loaded"));
}

function runTool() {
  const numeric_block_id = BLOCK_ID.substring(4);
  const block = document.querySelector(BLOCK_ID);
  block.classList.remove("r_hidden");

  const container = document.createElement("div");
  block.parentNode.insertBefore(container, block);
  block.remove();
  container.id = BLOCK_ID;

  const project_id = document
    .getElementById("allrecords")
    .getAttribute("data-tilda-project-id");
  const profile = JSON.parse(
    localStorage.getItem(`tilda_members_profile${project_id}`) || {}
  );
  profile["login"] = encodeURIComponent(profile["login"]);
  ["groups", "courses"].forEach((key) => delete profile[key]);
  const filters = new URLSearchParams(window.location.search).get(
    `filters${numeric_block_id}`
  );

  fetch(TOOLS_RUNNER_URL, {
    method: "POST",
    body: JSON.stringify({
      tool_id: TOOL_ID,
      profile: profile,
      project_id: project_id,
      referer: document.location.origin,
      user_agent: navigator.userAgent,
      filters: filters,
    }),
  })
    .then((response) =>
      response.json().then((data) => ({ error: !response.ok, data: data }))
    )
    .then(({ error, data }) => {
      if (error) {
        container.innerHTML = `Collabza (${BLOCK_ID}): ${data.message}`;
        container.style.textAlign = "center";
        return;
      }
      loadShowdown.then(() => {
        populate(container, block, data.records);
      });
    });
}
}
